@@ -3,10 +3,13 @@
 
 namespace Icinga\Module\Toplevelview\Controllers;
 
+use Icinga\Module\Toplevelview\Model\View;
 use Icinga\Module\Toplevelview\Forms\EditForm;
 use Icinga\Module\Toplevelview\ViewConfig;
 use Icinga\Module\Toplevelview\Web\Controller;
+
 use Icinga\Web\Url;
+use Icinga\Application\Icinga;
 
 class EditController extends Controller
 {
@@ -39,26 +42,43 @@ class EditController extends Controller
     {
         $action = $this->getRequest()->getActionName();
 
+        $config_dir_module = Icinga::app()
+                           ->getModuleManager()
+                           ->getModule('toplevelview')
+                           ->getConfigDir();
+
+        $c = new ViewConfig($config_dir_module);
+        $view = null;
+
         if ($action === 'add') {
             $this->view->title = sprintf('%s Top Level View', $this->translate('Add'));
-            $view = new ViewConfig();
-            $view->setConfigDir();
+            $view = new View('', $c::FORMAT_YAML);
         } elseif ($action === 'clone') {
+            // Clone the view and give it to the View
             $name = $this->params->getRequired('name');
             $this->view->title = sprintf('%s Top Level View', $this->translate('Clone'));
-            $view = clone ViewConfig::loadByName($name);
+
+            // Check if the user has permissions/restrictions for this View
+            $restrictions = $c->getRestrictions('toplevelview/filter/edit');
+            $c->assertAccessToView($restrictions, $name);
+
+            $view = clone $c->loadByName($name);
         } else {
             $this->view->name = $name = $this->params->getRequired('name');
             $this->view->title = sprintf('%s Top Level View: %s', $this->translate('Edit'), $this->params->getRequired('name'));
-            $view = ViewConfig::loadByName($name);
+
+            // Check if the user has permissions/restrictions for this View
+            $restrictions = $c->getRestrictions('toplevelview/filter/edit');
+            $c->assertAccessToView($restrictions, $name);
+
+            $view = $c->loadByName($name);
         }
 
         $this->view->form = $form = new EditForm();
+        $form->setViewConfig($c);
+        $form->setViews($view);
 
-        $view->setFormat(ViewConfig::FORMAT_YAML);
-        $form->setViewConfig($view);
         $form->handleRequest();
-
         $this->setViewScript('edit/index');
     }
 
