@@ -6,6 +6,8 @@ namespace Icinga\Module\Toplevelview\Controllers;
 use Icinga\Module\Toplevelview\ViewConfig;
 use Icinga\Module\Toplevelview\Web\Controller;
 
+use Icinga\Application\Icinga;
+
 /**
  * IndexController loads all existing Views from their YAML files.
  */
@@ -19,7 +21,15 @@ class IndexController extends Controller
         ])->activate('index');
 
         // Load add views from the existing YAML files
-        $this->view->views = ViewConfig::loadAll();
+        $config_dir_module = Icinga::app()
+                           ->getModuleManager()
+                           ->getModule('toplevelview')
+                           ->getConfigDir();
+
+        $c = new ViewConfig($config_dir_module);
+        $views = $c->loadAll();
+
+        $this->view->views = $views;
 
         $this->setAutorefreshInterval(30);
     }
