@@ -5,6 +5,10 @@ namespace Icinga\Module\Toplevelview\Tree;
 
 use Icinga\Exception\NotImplementedError;
 
+/**
+ * Leaf nodes that fetch data from the database are TLVIcingaNodes.
+ * @codeCoverageIgnore
+ */
 class TLVIcingaNode extends TLVTreeNode
 {
     protected static $canHaveChildren = false;
@@ -18,7 +22,7 @@ class TLVIcingaNode extends TLVTreeNode
      *
      * @throws NotImplementedError
      */
-    public static function fetch(/** @noinspection PhpUnusedParameterInspection */ TLVTree $root)
+    public static function fetch(/** @noinspection PhpUnusedParameterInspection */ TLVTree $root): void
     {
         throw new NotImplementedError('fetch() has not been implemented for %s', get_class(new static));
     }
