@@ -1,5 +1,7 @@
 ;(function (Icinga) {
 
+    'use strict';
+
     var Toplevelview = function (module) {
         this.module = module;
         this.initialize();
@@ -9,9 +11,13 @@
         initialize: function () {
             this.module.on('click', '.tlv-view-tree .tlv-tree-node', this.processTreeNodeClick);
             this.module.on('click', 'div[href].action', this.buttonClick, this);
+            this.module.on('click', '.btn-remove', this.onRemoveClick, this);
             this.module.on('rendered', this.rendered);
         },
 
+        /**
+         * rendered adds the CodeMirror editor to the designated div
+         */
         rendered: function (ev) {
             this.collapseOnLoad(ev);
             var $container = $(ev.currentTarget);
@@ -34,6 +40,9 @@
             });
         },
 
+        /**
+         * processTreeNodeClick toggles the collapsed status of the tree nodes
+         */
         processTreeNodeClick: function (event) {
             event.stopPropagation();
             var $el = $(event.currentTarget);
@@ -48,11 +57,26 @@
             }
         },
 
+        /**
+         * collapseOnLoad sets all OK nodes to collapsed,
+         * because these are not as interesting.
+         */
         collapseOnLoad: function (event) {
             var $el = $(event.currentTarget);
             $el.find('.tlv-view-tree .tlv-tree-node.tlv-collapsible.ok').addClass('tlv-collapsed');
         },
 
+        /**
+         * onRemoveClick shows a Browser confirmation windows.
+         */
+        onRemoveClick: function (event) {
+            event.stopPropagation();
+            let target = event.currentTarget;
+            const confirmMsg = target.getAttribute('data-confirmation');
+
+            return confirm(confirmMsg);
+        },
+
         buttonClick: function (event) {
             event.stopPropagation();
             var $el = $(event.currentTarget);
@@ -64,4 +88,5 @@
     };
 
     Icinga.availableModules.toplevelview = Toplevelview;
+
 }(Icinga));
